<?php
namespace Teknisa\OPL\Modules\Cadastros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Message;
use Teknisa\OPL\Modules\Cadastros\Services\sup03500ParametrizacaoProdutosSuprimentosService;
use Zeedhi\Framework\DTO\Response\Error;

class sup03500ParametrizacaoProdutosSuprimentosController extends \Teknisa\GER\Controllers\TeknisaCrud
{
    
    public function __construct($crudService, $parameterBag, sup03500ParametrizacaoProdutosSuprimentosService $service)
    {
        $this->crudService = $crudService;
        $this->service  = $service;
    }
    
    public function filtrar(DTO\Request\Filter $request, DTO\Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        
        $cdfilcentcmp = $this->service->getCentralCompras()[0]['CDFILCENTCMP'];
        
        $parametros = $this->service->getParametrosParasupri($cdfilcentcmp)[0];
        
        $cdgrupprod = $parametros['CDGRUPPROD'];
        
        $cdsubgrarvor = $parametros['CDSUBGRARVOR'];
        
        $param1 = [
            'columnName' => 'P_CDGRUPPROD',
            'operator'   => '=',
            'value'      => $cdgrupprod,
        ];
        
        $param2 = [
            'columnName' => 'P_CDSUBGRARVOR',
            'operator'   => '=',
            'value'      => $cdsubgrarvor,
        ];
        
        array_push($conditions, $param1, $param2);
        
        $filtrar = $this->crudService->getFilteredDataSet("sup03500_Filter", $conditions, $request->getFilterCriteria()->getPage(), $request->getFilterCriteria()->getPageSize())->getRows();;
       
        $response->addDataSet(new DataSet('sup03500_Filter', $filtrar));
    }
    
    public function unidadeFilter(DTO\Request\Filter $request, DTO\Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        
        $unidade = $this->crudService->getFilteredDataSet("sup03500_unidadeFilter", $conditions, $request->getFilterCriteria()->getPage(), $request->getFilterCriteria()->getPageSize())->getRows();;
       
        
        $response->addDataSet(new DataSet('sup03500_unidadeFilter', $unidade));
    }
    
    public function subGrupoFilter(DTO\Request\Filter $request, DTO\Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        
        $cdgrupprod = $this->service->selectCdgrupprod()[0]['CDGRUPPROD'];
        
        $conditions[] = [
            'columnName' => 'P_CDGRUPPROD',
            'operator'   => '=',
            'value'      => $cdgrupprod,
        ];
        
        $subGrupo = $this->crudService->getFilteredDataSet("sup03500_subGrupoFilter", $conditions, $request->getFilterCriteria()->getPage(), $request->getFilterCriteria()->getPageSize())->getRows();
            
        $response->addDataSet(new DataSet('sup03500_subGrupoFilter', $subGrupo));
    }
    
    public function procedureExcInc(DTO\Request\Row $request, DTO\Response $response)
	{
		try {
            $row = $request->getRow();
            
            $cdgrupprod = $this->service->selectCdgrupprod()[0]['CDGRUPPROD'];
            
            $row['CDGRUPPROD'] = $cdgrupprod;
			
			$procedureResult = $this->service->procedureExcInc($row);
			
			if($procedureResult['P_RESULTADO'] == 'NAO_INSERT'){
			    throw new \Exception("Não há dados!");
			}
			
			$response->addMessage(new Message("Operação realizada com sucesso."));
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
	}
	
	public function unidadeExcInc(DTO\Request\Filter $request, DTO\Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        
        $unidade = $this->crudService->getFilteredDataSet("sup03500_unidadeExcInc", $conditions, $request->getFilterCriteria()->getPage(), $request->getFilterCriteria()->getPageSize())->getRows();;
       
        
        $response->addDataSet(new DataSet('sup03500_unidadeExcInc', $unidade));
    }
    
    public function subGrupoExcInc(DTO\Request\Filter $request, DTO\Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        
        $cdgrupprod = $this->service->selectCdgrupprod()[0]['CDGRUPPROD'];
        
        $conditions[] = [
            'columnName' => 'P_CDGRUPPROD',
            'operator'   => '=',
            'value'      => $cdgrupprod,
        ];
        
        $subGrupo = $this->crudService->getFilteredDataSet("sup03500_subGrupoExcInc", $conditions, $request->getFilterCriteria()->getPage(), $request->getFilterCriteria()->getPageSize())->getRows();
            
        $response->addDataSet(new DataSet('sup03500_subGrupoExcInc', $subGrupo));
    }
}